==> org.eclipse.wb.swing.MigLayout.source_1.9.3.202308291944.jar: org/eclipse/wb/internal/swing/MigLayout/model/ui/ColumnEditDialog.java <==
/*******************************************************************************
 * Copyright (c) 2011 Google, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Google, Inc. - initial API and implementation
 *******************************************************************************/
package org.eclipse.wb.internal.swing.MigLayout.model.ui;

import com.google.common.collect.Lists;

import org.eclipse.wb.internal.swing.MigLayout.model.MigColumnInfo;
import org.eclipse.wb.internal.swing.MigLayout.model.MigColumnInfo.Alignment;
import org.eclipse.wb.internal.swing.MigLayout.model.MigLayoutInfo;
import org.eclipse.wb.internal.swing.MigLayout.model.ModelMessages;

import org.eclipse.swt.widgets.Shell;

import java.util.List;

/**
 * The dialog for editing {@link MigColumnInfo}.
 *
 * @author scheglov_ke
 * @coverage swing.MigLayout.ui
 */
public final class ColumnEditDialog extends DimensionEditDialog<MigColumnInfo, Alignment> {
	private static final List<AlignmentDescription<Alignment>> ALIGNMENTS = Lists.newArrayList();
	static {
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.DEFAULT,
				ModelMessages.ColumnEditDialog_alignmentDefault));
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.LEFT,
				ModelMessages.ColumnEditDialog_alignmentLeft));
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.CENTER,
				ModelMessages.ColumnEditDialog_alignmentCenter));
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.RIGHT,
				ModelMessages.ColumnEditDialog_alignmentRight));
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.FILL,
				ModelMessages.ColumnEditDialog_alignmentFill));
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.LEADING,
				ModelMessages.ColumnEditDialog_alignmentLeading));
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.TRAILING,
				ModelMessages.ColumnEditDialog_alignmentTrailing));
	}

	////////////////////////////////////////////////////////////////////////////
	//
	// Constructor
	//
	////////////////////////////////////////////////////////////////////////////
	public ColumnEditDialog(Shell parentShell, MigLayoutInfo layout, MigColumnInfo column) {
		super(parentShell,
				layout,
				layout.getColumns(),
				column,
				ModelMessages.ColumnEditDialog_title,
				ALIGNMENTS);
	}

	////////////////////////////////////////////////////////////////////////////
	//
	// Internal access
	//
	////////////////////////////////////////////////////////////////////////////
	@Override
	protected Alignment getAlignment(MigColumnInfo dimension) {
		return dimension.getAlignment(false);
	}

	@Override
	protected void setAlignment(MigColumnInfo dimension, Alignment alignment) {
		dimension.setAlignment(alignment);
	}
}

==> org.eclipse.wb.swing.MigLayout.source_1.11.0.202501281906.jar: org/eclipse/wb/internal/swing/MigLayout/model/ui/ColumnEditDialog.java <==
/*******************************************************************************
 * Copyright (c) 2011 Google, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Google, Inc. - initial API and implementation
 *******************************************************************************/
package org.eclipse.wb.internal.swing.MigLayout.model.ui;

import org.eclipse.wb.internal.swing.MigLayout.model.MigColumnInfo;
import org.eclipse.wb.internal.swing.MigLayout.model.MigColumnInfo.Alignment;
import org.eclipse.wb.internal.swing.MigLayout.model.MigLayoutInfo;
import org.eclipse.wb.internal.swing.MigLayout.model.ModelMessages;

import org.eclipse.swt.widgets.Shell;

import java.util.ArrayList;
import java.util.List;

/**
 * The dialog for editing {@link MigColumnInfo}.
 *
 * @author scheglov_ke
 * @coverage swing.MigLayout.ui
 */
public final class ColumnEditDialog extends DimensionEditDialog<MigColumnInfo, Alignment> {
	private static final List<AlignmentDescription<Alignment>> ALIGNMENTS = new ArrayList<>();
	static {
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.DEFAULT,
				ModelMessages.ColumnEditDialog_alignmentDefault));
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.LEFT,
				ModelMessages.ColumnEditDialog_alignmentLeft));
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.CENTER,
				ModelMessages.ColumnEditDialog_alignmentCenter));
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.RIGHT,
				ModelMessages.ColumnEditDialog_alignmentRight));
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.FILL,
				ModelMessages.ColumnEditDialog_alignmentFill));
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.LEADING,
				ModelMessages.ColumnEditDialog_alignmentLeading));
		ALIGNMENTS.add(new AlignmentDescription<>(Alignment.TRAILING,
				ModelMessages.ColumnEditDialog_alignmentTrailing));
	}

	////////////////////////////////////////////////////////////////////////////
	//
	// Constructor
	//
	////////////////////////////////////////////////////////////////////////////
	public ColumnEditDialog(Shell parentShell, MigLayoutInfo layout, MigColumnInfo column) {
		super(parentShell,
				layout,
				layout.getColumns(),
				column,
				ModelMessages.ColumnEditDialog_title,
				ALIGNMENTS);
	}

	////////////////////////////////////////////////////////////////////////////
	//
	// Internal access
	//
	////////////////////////////////////////////////////////////////////////////
	@Override
	protected Alignment getAlignment(MigColumnInfo dimension) {
		return dimension.getAlignment(false);
	}

	@Override
	protected void setAlignment(MigColumnInfo dimension, Alignment alignment) {
		dimension.setAlignment(alignment);
	}
}
